==> vue-fetch-plugin-1.1.5.tgz: package/src/index.js <==
import fetch from 'isomorphic-fetch';

const opts = {
  resFilter: (result) => {
    return result.json();
  },
  resError: (res) => {
    return false
  }
};

function myFetch(url, opt) {
  return new Promise((resolve, reject) => {
    fetch(url, opt)
      .then((response) => {
        if (response.status >= 400) {
          const error = opts.resError(response);
          if (error) {
            resolve(error);
          } else {
            throw new Error(response.statusText);
          }
        } else {
          resolve(response.json());
        }
      })
      .then((e) => {
        reject(e);
      })
  });
}

async function $fetch(url, option = {}) {
  const result = await myFetch(url, option);
  const handle = opts.resFilter(result);
  return handle ? handle : result;
}

async function $get(url) {
  const getOpts = Object.assign({
    method: 'GET'
  }, opts);
  const result = await myFetch(`${url}?t=${+new Date()}`, getOpts);
  const handle = opts.resFilter(result);
  return handle ? handle : result;
}

async function $post(url, data) {
  const postOpts = Object.assign({
    method: 'POST'
  }, opts);
  if (data) {
    postOpts.body = JSON.stringify(data);
  }
  const result = await myFetch(url, postOpts);
  const handle = opts.resFilter(result);
  return handle ? handle : result;
}

export default {
  fetch: $fetch,
  get: $get,
  post: $post,
  install: (Vue, options) => {
    Object.assign(opts, options);
    Vue.mixin({
      methods: {
        $fetch,
        $get,
        $post
      }
    });
  }
};

==> vue-fetch-plugin-1.2.5.tgz: package/src/index.js <==
import fetch from 'isomorphic-fetch';

const opts = {
  formatData: (data) => {
    return data;
  },
  resFilter: (result) => {
    return result.json();
  },
  resError: (res) => {
    return false
  }
};

function myFetch(url, opt) {
  return new Promise((resolve, reject) => {
    fetch(url, opt)
      .then((response) => {
        if (response.status >= 400) {
          const error = opts.resError(response);
          if (error) {
            resolve(error);
          } else {
            throw new Error(response.statusText);
          }
        } else {
          resolve(response.json());
        }
      })
      .then((e) => {
        reject(e);
      })
  });
}

async function $fetch(url, option = {}) {
  const result = await myFetch(url, option);
  const handle = opts.resFilter(result);
  return handle ? handle : result;
}

async function $get(url) {
  const getOpts = Object.assign({
    method: 'GET'
  }, opts);
  const result = await myFetch(`${url}?t=${+new Date()}`, getOpts);
  const handle = opts.resFilter(result);
  return handle ? handle : result;
}

async function $post(url, data) {
  const postOpts = Object.assign({
    method: 'POST'
  }, opts);
  if (data) {
    postOpts.body = JSON.stringify(opts.formatData(data));
  }
  const result = await myFetch(url, postOpts);
  const handle = opts.resFilter(result);
  return handle ? handle : result;
}

export default {
  fetch: $fetch,
  get: $get,
  post: $post,
  install: (Vue, options) => {
    Object.assign(opts, options);
    Vue.mixin({
      methods: {
        $fetch,
        $get,
        $post
      }
    });
  }
};
